@@ -44,6 +44,10 @@ class VpnCli:
         )
         output = pipe.readlines()
 
+        # OSX reads always as bytes
+        if type(output) == bytes:
+            output = output.decode()
+
         if "disconnected" in "".join(output[-3:-1]).lower():
             print("Disconnected")
         else:
@@ -68,6 +72,10 @@ class VpnCli:
             self.process_pipe.sendline("y")
 
         output = self.process_pipe.readlines()
+        # OSX reads always as bytes
+        if type(output) == bytes:
+            output = output.decode()
+
         logging.info("".join(output))
         return "connected" in "".join(output[-3:-1]).lower()
 
@@ -83,7 +91,7 @@ class VpnCli:
 
     @classmethod
     def check_containing(
-        cls, read_lines: str, searched_list: tuple
+            cls, read_lines: str, searched_list: tuple
     ) -> Union[
         Match[str], None, Match[Union[Union[str, bytes], Any]], tuple[bool, None]
     ]:
